@@ -143,7 +143,7 @@ def train_from_cfg(cfg: DictConfig) -> Type[nn.Module]:
     rundir = os.getcwd()  # done by hydra
 
     device = torch.device("cuda:" + str(cfg.compute.gpu_id) if torch.cuda.is_available() else "cpu")
-    torch.cuda.set_device(device)
+    if device != 'cpu': torch.cuda.set_device(device)
 
     flow_generator = build_flow_generator(cfg)
     flow_weights = get_weightfile_from_cfg(cfg, 'flow_generator')
@@ -663,9 +663,9 @@ def speedtest(loader, model, metrics, steps, supervised: bool = True, device=Non
 
         # N,C,H,W = images.shape
         num_images = inputs.shape[0]
-        time_per_image = (time.time() - t0) / num_images
+        time_per_image = (time.time() - t0) / (num_images + 1e-7)
         metrics.time_append(time_per_image)
-        t.set_description('FPS: {:.2f}'.format(1 / time_per_image))
+        t.set_description('FPS: {:.2f}'.format(1 / (time_per_image + 1e-7)))
     metrics.end_epoch_speedtest()
     return metrics
 
