@@ -67,7 +67,29 @@ def read_label_csv(labelfile):
     label = df.values.astype(np.int64)
     if label.ndim == 1:
         label = label[..., np.newaxis]
-    return (label)
+    return label
+
+
+def convert_video(videofile: Union[str, os.PathLike], movie_format: str, *args,
+                  **kwargs) -> None:
+    with VideoReader(videofile) as reader:
+        basename = os.path.splitext(videofile)[0]
+        if movie_format == 'ffmpeg':
+            out_filename = basename + '.mp4'
+        elif movie_format == 'opencv':
+            out_filename = basename + '.avi'
+        elif movie_format == 'hdf5':
+            out_filename = basename + '.h5'
+        elif movie_format == 'directory':
+            out_filename = basename
+        else:
+            raise ValueError('unexpected value of movie format: {}'.format(movie_format))
+        with VideoWriter(out_filename,
+                         movie_format=movie_format,
+                         *args,
+                         **kwargs) as writer:
+            for frame in reader:
+                writer.write(frame)
 
 
 class VideoPlayer:
@@ -181,7 +203,7 @@ class VideoReader:
             VideoReader object
         """
         if not os.path.isfile(filename):
-            assert (os.path.isdir(filename))
+            assert os.path.isdir(filename)
             self.filetype = 'directory'
             endings = ['.bmp', '.jpg', '.png', '.jpeg', '.tiff', '.tif']
             files = os.listdir(filename)
@@ -197,13 +219,13 @@ class VideoReader:
             self.nframes = len(self.file_object)
         else:
             _, ext = os.path.splitext(filename)
-            ext = ext[1:]
+            ext = ext[1:].lower()
 
             if ext == 'h5':
                 self.filetype = 'hdf5'
                 self.file_object = h5py.File(filename, 'r')
                 self.nframes = len(self.file_object['frame'])
-            elif ext == 'avi' or ext == 'mp4':
+            elif ext == 'avi' or ext == 'mp4' or ext == 'mov':
                 self.filetype = 'video'
                 self.file_object = cv2.VideoCapture(filename)
                 self.nframes = int(self.file_object.get(cv2.CAP_PROP_FRAME_COUNT))
@@ -318,10 +340,10 @@ def write_frame_hdf5(writer_obj, frame, axis=0, quality: int = 80):
     """ Writes frames to an HDF5 file by encoding them as JPEG bytestrings """
     # ret1, left_jpg = cv2.imencode('.jpg', left, (cv2.IMWRITE_JPEG_QUALITY,80))
     # ret2, right_jpg = cv2.imencode('.jpg', right, (cv2.IMWRITE_JPEG_QUALITY,80))
-    ret, jpg = cv2.imencode('.jpg', frame, (cv2.IMWRITE_JPEG_QUALITY, quality))
+    ret, encoded = cv2.imencode('.png', frame)
     writer_obj['frame'].resize(writer_obj['frame'].shape[axis] + 1, axis=axis)
     # f['left'].resize(f['left'].shape[axis]+1, axis=axis)
-    writer_obj['frame'][-1] = jpg.squeeze()
+    writer_obj['frame'][-1] = encoded.squeeze()
 
 
 def initialize_opencv(filename, framesize, codec, fps: float = 30.0):
@@ -449,8 +471,8 @@ class VideoWriter:
 
     OpenCV: can use encode using MJPG, XVID / DIVX, uncompressed bitmaps, or FFV1 (lossless) encoding
     FFMPEG: can use many codecs, but here only libx264, a common encoder with very high compression rates
-    HDF5: Encodes each image as a jpg, and stores as an array of these jpg encoded bytestrings
-        Very similar filesize to MJPG encoding, but dramatically faster RANDOM reads!
+    HDF5: Encodes each image as a jpg, and stores as an array of these png encoded bytestrings
+        Lossless encoding for larger file sizes, but dramatically faster RANDOM reads!
         Good for if you need often to grab a random frame from anywhere within a video, but slightly slower for
         reading sequential frames.
     directory: encodes each image as a .jpg, .png, .tiff, .bmp, etc. Saves with filename starting at 000000000.jpg
@@ -489,10 +511,12 @@ class VideoWriter:
         Returns:
             VideoWriter object
         """
-        assert (movie_format in ['opencv', 'hdf5', 'ffmpeg', 'directory'])
+        assert movie_format in ['opencv', 'hdf5', 'ffmpeg', 'directory']
         self.filename = filename
         if movie_format == 'directory':
-            assert (filetype in ['.bmp', '.jpg', '.png', '.jpeg', '.tiff', '.tif'])
+            assert filetype in ['.bmp', '.jpg', '.png', '.jpeg', '.tiff', '.tif']
+            # make sure we don't have any endings
+            self.filename = os.path.splitext(self.filename)[0]
             # save it as "codec" so that initialization and write funcs have this info
             self.codec = filetype
         else:
@@ -500,6 +524,9 @@ class VideoWriter:
             if movie_format == 'opencv' or movie_format == 'ffmpeg':
                 assert (ext in ['.avi', '.mp4'])
             self.codec = codec
+        self.verbose = verbose
+        if os.path.exists(self.filename):
+            raise ValueError('File already exists! {}'.format(self.filename))
         self.height = height
         self.width = width
 
@@ -510,7 +537,7 @@ class VideoWriter:
 
         self.colorspace = colorspace
         assert (self.colorspace in ['BGR', 'RGB', 'GRAY'])
-        self.verbose = verbose
+
         self.asynchronous = asynchronous
 
         if movie_format == 'hdf5':
@@ -627,9 +654,9 @@ class VideoWriter:
 
     def __exit__(self, type, value, traceback):
         # allows use with decorator
-        self.stop()
+        self.close()
 
-    def stop(self):
+    def close(self):
         """Stops writing, closes all open file objects"""
         if self.has_stopped:
             return
@@ -659,7 +686,7 @@ class VideoWriter:
     def __del__(self):
         """Destructor"""
         try:
-            self.stop()
+            self.close()
         except BaseException as e:
             if self.verbose:
                 print('Error in destructor')
