@@ -7,11 +7,11 @@ from typing import Union, Type
 import hydra
 import matplotlib.pyplot as plt
 import numpy as np
-from omegaconf import DictConfig
 import torch
 import torch.backends.cudnn as cudnn
 import torch.nn as nn
 import torch.optim as optim
+from omegaconf import DictConfig
 
 try:
     from torch.cuda.amp import autocast, GradScaler
@@ -76,7 +76,7 @@ def build_model_from_cfg(cfg: DictConfig) -> Type[nn.Module]:
 
 def train_from_cfg(cfg: DictConfig) -> Type[nn.Module]:
     device = torch.device("cuda:" + str(cfg.compute.gpu_id) if torch.cuda.is_available() else "cpu")
-    torch.cuda.set_device(device)
+    if device != 'cpu': torch.cuda.set_device(device)
 
     log.info('Training flow generator....')
 
@@ -407,9 +407,9 @@ def speedtest(loader, model, metrics, steps, device=None, dali:bool=False, fp16:
 
         # N,C,H,W = images.shape
         num_images = batch.shape[0]
-        time_per_image = (time.time() - t0) / num_images
+        time_per_image = (time.time() - t0) / (num_images + 1e-7)
         metrics.time_append(time_per_image)
-        t.set_description('FPS: {:.2f}'.format(1 / time_per_image))
+        t.set_description('FPS: {:.2f}'.format(1 / (time_per_image + 1e-7)))
     total_t = time.time() - epoch_t
     batches_per_s = total_t / num_iters
     log.debug('batches per second in speedtest: {}'.format(batches_per_s))
