@@ -10,11 +10,12 @@ import h5py
 import numpy as np
 import pandas as pd
 from omegaconf import DictConfig
+from tqdm import tqdm
 
 from deepethogram.utils import get_subfiles
 from deepethogram.zscore import zscore_video
 from . import utils
-from .file_io import read_labels
+from .file_io import read_labels, convert_video
 
 log = logging.getLogger(__name__)
 
@@ -105,7 +106,13 @@ def add_video_to_project(project: dict, path_to_video: Union[str, os.PathLike],
         path to the video file after moving to the DEG project data directory.
     """
     # assert (os.path.isdir(project_directory))
-    assert os.path.isfile(path_to_video), 'video not found! {}'.format(path_to_video)
+    if os.path.isdir(path_to_video):
+        copy_func = shutil.copytree
+    elif os.path.isfile(path_to_video):
+        copy_func = shutil.copy
+    else:
+        raise ValueError('video does not exist: {}'.format(path_to_video))
+
     assert mode in ['copy', 'symlink', 'move']
 
     # project = utils.load_yaml(os.path.join(project_directory, 'project_config.yaml'))
@@ -124,7 +131,7 @@ def add_video_to_project(project: dict, path_to_video: Union[str, os.PathLike],
     os.makedirs(video_directory)
     new_path = os.path.join(video_directory, basename)
     if mode == 'copy':
-        shutil.copy(path_to_video, new_path)
+        copy_func(path_to_video, new_path)
     elif mode == 'symlink':
         os.symlink(path_to_video, new_path)
     elif mode == 'move':
@@ -203,13 +210,23 @@ def is_deg_file(filename: Union[str, os.PathLike]) -> bool:
     """Quickly assess if a file is part of a well-formatted subdirectory with a records.yaml"""
     if os.path.isdir(filename):
         basedir = filename
+        is_directory = True
     elif os.path.isfile(filename):
         basedir = os.path.dirname(filename)
+        is_directory = False
     else:
         raise ValueError('submit directory or file to is_deg_file, not {}'.format(filename))
 
     recordfile = os.path.join(basedir, 'record.yaml')
-    return os.path.isfile(recordfile)
+    record_exists = os.path.isfile(recordfile)
+
+    if is_directory:
+        # this is required in case the file passed is a directory full of images; e.g.
+        # project/DATA/animal0/images/00000.jpg
+        parent_record_exists = os.path.isfile(os.path.join(os.path.dirname(filename), 'record.yaml'))
+        return record_exists or parent_record_exists
+    else:
+        return record_exists
 
 
 def add_behavior_to_project(config_file: Union[str, os.PathLike], behavior_name: str):
@@ -349,7 +366,7 @@ def find_labelfiles(root: Union[str, bytes, os.PathLike]) -> list:
         files: list of score or label files
     """
     files = get_subfiles(root, return_type='file')
-    files = [i for i in files if 'label' in os.path.basename(i) or 'score' in os.path.basename(i)]
+    files = [i for i in files if 'label' in os.path.basename(i).lower() or 'score' in os.path.basename(i).lower()]
     return files
 
 
@@ -364,9 +381,9 @@ def find_rgbfiles(root: Union[str, bytes, os.PathLike]) -> list:
     """
     files = get_subfiles(root, return_type='any')
     endings = [os.path.splitext(i)[1] for i in files]
-    valid_endings = ['.avi', '.mp4', '.h5']
+    valid_endings = ['.avi', '.mp4', '.h5', '.mov']
     excluded = ['flow', 'label', 'output', 'score']
-    movies = [i for i in files if os.path.splitext(i)[1] in valid_endings]
+    movies = [i for i in files if os.path.splitext(i)[1].lower() in valid_endings]
     movies = exclude_strings_from_filelist(movies, excluded)
 
     framedirs = get_subfiles(root, return_type='directory')
@@ -403,7 +420,7 @@ def find_outputfiles(root: Union[str, bytes, os.PathLike]) -> list:
         list of outputfiles. should only have one element
     """
     files = get_subfiles(root, return_type='file')
-    files = [i for i in files if 'output' in os.path.basename(i) and os.path.splitext(i)[1] == '.h5']
+    files = [i for i in files if 'output' in os.path.basename(i).lower() and os.path.splitext(i)[1].lower() == '.h5']
     return files
 
 
@@ -574,11 +591,8 @@ def get_record_from_subdir(subdir: Union[str, os.PathLike]) -> dict:
         stats: yaml file containing that video's RGB channel statistics
         key: basename of this directory. e.g. animal0
     """
-    file = os.path.join(subdir, 'record.yaml')
-    if not os.path.isfile(file):
-        record = parse_subdir(subdir)
-    else:
-        record = utils.load_yaml(file)
+    record = parse_subdir(subdir)
+
     parsed_record = {}
     for key in ['flow', 'label', 'output', 'rgb']:
         if key in list(record.keys()):
@@ -620,7 +634,7 @@ def get_records_from_datadir(datadir: Union[str, bytes, os.PathLike]) -> dict:
     subdirs = get_subfiles(datadir, return_type='directory')
     records = {}
     for subdir in subdirs:
-        parsed_record = get_record_from_subdir(os.path.join(datadir, subdir))
+        parsed_record = get_record_from_subdir(os.path.join(datadir, subdir) )
         records[parsed_record['key']] = parsed_record
     write_all_records(datadir)
     return records
@@ -772,6 +786,8 @@ def import_outputfile(project_dir: Union[str, os.PathLike], outputfile: Union[st
 
         thresholds = f[key]['thresholds'][:]
         loaded_class_names = f[key]['class_names'][:]
+        if type(loaded_class_names[0]) == bytes:
+            loaded_class_names = [i.decode('utf-8') for i in loaded_class_names]
     log.debug('probabilities shape: {}'.format(probabilities.shape))
 
     # if you pass class names, make sure that the order matches the order of the argument. Else, just return it
@@ -1002,7 +1018,9 @@ def get_weightfile_from_cfg(cfg: DictConfig, model_type: str) -> Union[str, None
             return cfg[model_type].weights
         elif cfg.reload.latest or cfg[model_type].weights == 'latest':
             # print(trained_models)
-            assert len(trained_models[model_type][architecture]) > 0
+            if len(trained_models[model_type][architecture]) == 0:
+                log.warning('Trying to load *latest* weights, but found none! Using random initialization!')
+                return
             log.debug('trained models found: {}'.format(trained_models[model_type][architecture]))
             log.info('loading LATEST weights: {}'.format(trained_models[model_type][architecture][-1]))
             return trained_models[model_type][architecture][-1]
@@ -1074,3 +1092,16 @@ def load_default(conf_name: str) -> dict:
 
     defaults = utils.load_yaml(defaults_file)
     return defaults
+
+def convert_all_videos(config_file: Union[str, os.PathLike], movie_format='hdf5') -> None:
+    assert os.path.isfile(config_file)
+    project_config = utils.load_yaml(config_file)
+
+    records = get_records_from_datadir(os.path.join(project_config['project']['path'],
+                                                    project_config['project']['data_path']))
+    for key, record in tqdm(records.items(), desc='converting videos'):
+        videofile = record['rgb']
+        try:
+            convert_video(videofile, movie_format=movie_format)
+        except ValueError as e:
+            print(e)
